@@ -50,18 +50,23 @@ class Freebox(IPlugin):
 		for rs in self.configuration_plugin['param_fb']:
 			log.msg("ids  :  %s" % (rs['ids']))
 			if rs['ids'] == idex :
-
-				if rs['idx_sec'] <> "":
+				log.msg("*************  TROUVé ****************")
+				if rs['idx_sec'] <> "1":
+					log.msg("*************  'idx_sec'] <> "1" ****************")
 					# séparation de rs['idx'], nombre  
 					# search position '|' dans rs['idx']	
 					bodies = rs['boy']
 					log.msg("BODIES  :  %s" % (bodies))
 					log.msg("number  :  %s" % (int(rs['idx'])))
 		# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
-				for rx in range (1, int(rs['idx_sec'])): 				
+					for rx in range (1, int(rs['idx_sec'])): 				
+						resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
+						log.msg("resp  :  %s" % (resp))
+				else:
+					log.msg("*************  'idx_sec'] = "1" ****************")
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
-					log.msg("resp  :  %s" % (resp))
-			
+				
+				
 		if bodies == "":
 			bodies = "j'ai rien compris aux switch"
 		return {"plugin": "Freebox",
